==> v5.1.1.tar.gz: barker/bookie/src/app/menu-category/menu-category-detail/menu-category-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { MenuCategory } from '../../core/menu-category';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { MenuCategoryService } from '../menu-category.service';

@Component({
  selector: 'app-menu-category-detail',
  templateUrl: './menu-category-detail.component.html',
  styleUrls: ['./menu-category-detail.component.css'],
})
export class MenuCategoryDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup;
  item: MenuCategory = new MenuCategory();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: MenuCategoryService,
  ) {
    // Create form
    this.form = this.fb.group({
      name: '',
      discountLimit: '',
      isActive: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: MenuCategory };
      this.showItem(data.item);
    });
  }

  showItem(item: MenuCategory) {
    this.item = item;
    this.form.setValue({
      name: this.item.name,
      discountLimit: this.item.discountLimit,
      isActive: this.item.isActive,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/menu-categories');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/menu-categories');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Menu Category?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): MenuCategory {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.discountLimit = +formModel.discountLimit;
    this.item.isActive = formModel.isActive;
    return this.item;
  }
}

==> v11.6.2.tar.gz: barker/bookie/src/app/menu-category/menu-category-detail/menu-category-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { MenuCategory } from '../../core/menu-category';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { MenuCategoryService } from '../menu-category.service';

@Component({
  selector: 'app-menu-category-detail',
  templateUrl: './menu-category-detail.component.html',
  styleUrls: ['./menu-category-detail.component.css'],
})
export class MenuCategoryDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    name: FormControl<string>;
    isActive: FormControl<boolean>;
  }>;

  item: MenuCategory = new MenuCategory();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private toaster: ToasterService,
    private ser: MenuCategoryService,
  ) {
    // Create form
    this.form = new FormGroup({
      name: new FormControl<string>('', { nonNullable: true }),
      isActive: new FormControl<boolean>(true, { nonNullable: true }),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: MenuCategory };
      this.showItem(data.item);
    });
  }

  showItem(item: MenuCategory) {
    this.item = item;
    this.form.setValue({
      name: this.item.name,
      isActive: this.item.isActive,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/menu-categories');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/menu-categories');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Menu Category?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): MenuCategory {
    const formModel = this.form.value;
    this.item.name = formModel.name ?? '';
    this.item.isActive = formModel.isActive ?? true;
    return this.item;
  }
}
